==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
var DataLegendSummaryColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryColumnDescriptionMetadata, _super);
    function DataLegendSummaryColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryColumnDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
            DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        if (a.k(DataLegendSummaryColumnDescriptionMetadata.a)) {
            return;
        }
        a.ab(DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.c = function (a) {
        DataLegendSeriesValueInfoDescriptionMetadata.c(a);
    };
    DataLegendSummaryColumnDescriptionMetadata.d = function (a) {
        DataLegendSummaryColumnDescriptionMetadata.b(a);
        a.ad("DataLegendSummaryColumn", function () { return new DataLegendSummaryColumnDescription(); });
        a.ac("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.$t = markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
}(Base));
export { DataLegendSummaryColumnDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
var DataLegendSummaryColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryColumnDescriptionMetadata, _super);
    function DataLegendSummaryColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryColumnDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
            DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        if (a.k(DataLegendSummaryColumnDescriptionMetadata.a)) {
            return;
        }
        a.ac(DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.c = function (a) {
        DataLegendSeriesValueInfoDescriptionMetadata.c(a);
    };
    DataLegendSummaryColumnDescriptionMetadata.d = function (a) {
        DataLegendSummaryColumnDescriptionMetadata.b(a);
        a.ae("DataLegendSummaryColumn", function () { return new DataLegendSummaryColumnDescription(); });
        a.ad("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.$t = markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
}(Base));
export { DataLegendSummaryColumnDescriptionMetadata };
